@@ -108,6 +108,7 @@ setGeneric("is.published<-", function (x, value) standardGeneric("is.published<-
 setGeneric("groupClass", function (x) standardGeneric("groupClass"))
 setGeneric("entityClass", function (x) standardGeneric("entityClass"))
 setGeneric("entitiesInitializer", function (x) standardGeneric("entitiesInitializer"))
+setGeneric("weightVariables", function (x) standardGeneric("weightVariables"))
 
 setGeneric("owner", function (x) standardGeneric("owner"))
 setGeneric("owner<-", function (x, value) standardGeneric("owner<-"))
@@ -129,6 +130,7 @@ setGeneric("prop.table")
 setGeneric("round")
 
 setGeneric("bases", function (x, margin=NULL) standardGeneric("bases"))
+setGeneric("dimensions", function (x) standardGeneric("dimensions"))
 
 setGeneric("subset")
 setGeneric("which", signature="x")
