@@ -60,18 +60,20 @@ addVariables <- function (dataset, ...) {
 
 validateVarDefRows <- function (vardef, numrows) {
     ## Pre-check the column length being sent to the server to confirm that
-    ## the number of rows matches what's already in the dataset
-    if (!any(c("expr", "subvariables") %in% names(vardef))) {
+    ## the number of rows matches what's already in the dataset.
+    if (!any(c("expr", "derivation", "subvariables") %in% names(vardef))) {
         new <- length(vardef$values)
-        old <- numrows ## Just for naming clarity
-        if (new == 1 && old > 1) {
-            vardef$values <- rep(vardef$values, old)
-            new <- old
-        }
         if (new == 0) {
             warning("Adding variable with no rows of data", call.=FALSE)
-        } else if (old > 0 && new != old) {
-            halt("replacement has ", new, " rows, data has ", old)
+        } else if (numrows > 0 && new > 1 && new != numrows) {
+            halt("replacement has ", new, " rows, data has ", numrows)
+        }
+        uniques <- unique(vardef$values)
+        if (numrows > 0 && length(uniques) == 1) {
+            ## Just send the unique value to save bandwidth
+            ## TODO: Move this somewhere else so that it's not a side effect
+            ## of "validation"
+            vardef$values <- uniques
         }
     }
     return(vardef)
@@ -81,7 +83,7 @@ POSTNewVariable <- function (catalog_url, variable) {
 
     do.POST <- function (x) crPOST(catalog_url, body=toJSON(x, digits=15))
 
-    if (!("expr" %in% names(variable))) {
+    if (!any(c("expr", "derivation") %in% names(variable))) {
         ## If deriving a variable, skip this and go straight to POSTing
         if (variable$type %in% c("multiple_response", "categorical_array")) {
             ## Assumes: array of subvariables included, and if MR, at least one
