@@ -19,8 +19,7 @@ forks <- function (dataset) {
 #' @export
 forkDataset <- function (dataset, name=defaultForkName(dataset), draft=FALSE, ...) {
     fork_url <- crPOST(shojiURL(dataset, "catalogs", "forks"),
-        body=toJSON(list(element="shoji:entity",
-                         body=list(name=name, is_published=!draft, ...))))
+        body=toJSON(wrapEntity(name=name, is_published=!draft, ...)))
     dropOnly(sessionURL("datasets"))
     invisible(entity(datasets()[[fork_url]]))
 }
@@ -51,12 +50,11 @@ mergeFork <- function (dataset, fork, autorollback=TRUE, force=FALSE) {
     prompt <- paste("Force merge discards any additions or edits to the target",
         "dataset that occurred after the point the fork was created. It cannot",
         "be reverted or otherwise undone. Are you sure you want to continue?")
-    if (force && requireConsent() && !askForPermission(prompt)) {
+    if (force && !askForPermission(prompt)) {
         halt("Must confirm force merge")
     }
-    m <- crPOST(shojiURL(dataset, "catalogs", "actions"), body=toJSON(list(
-        element="shoji:entity",
-        body=list(dataset=self(fork), autorollback=autorollback, force=force)
-    )))
+    payload <- wrapEntity(dataset=self(fork), autorollback=autorollback,
+        force=force)
+    m <- crPOST(shojiURL(dataset, "catalogs", "actions"), body=toJSON(payload))
     return(refresh(dataset))
 }
