@@ -20,10 +20,10 @@ with_mock_HTTP({
 
     test_that("Dataset attribute setting", {
         expect_PATCH(name(ds) <- "New name",
-            "api/datasets/",
-            '{"api/datasets/1/":{"name":"New name"}}')
+            "https://app.crunch.io/api/datasets/",
+            '{"https://app.crunch.io/api/datasets/1/":{"name":"New name"}}')
         expect_PATCH(notes(ds) <- "Ancillary information",
-            "api/datasets/1/",
+            "https://app.crunch.io/api/datasets/1/",
             '{"notes":"Ancillary information"}')
     })
 
@@ -42,11 +42,11 @@ with_mock_HTTP({
 
     test_that("archive setting", {
         expect_PATCH(is.archived(ds2) <- TRUE,
-            'api/datasets/',
-            '{"api/datasets/3/":{"archived":true}}')
+            'https://app.crunch.io/api/datasets/',
+            '{"https://app.crunch.io/api/datasets/3/":{"archived":true}}')
         expect_PATCH(archive(ds2),
-            'api/datasets/',
-            '{"api/datasets/3/":{"archived":true}}')
+            'https://app.crunch.io/api/datasets/',
+            '{"https://app.crunch.io/api/datasets/3/":{"archived":true}}')
     })
 
     test_that("draft/published", {
@@ -58,20 +58,20 @@ with_mock_HTTP({
 
     test_that("draft/publish setting", {
         expect_PATCH(is.published(ds2) <- TRUE,
-            'api/datasets/',
-            '{"api/datasets/3/":{"is_published":true}}')
+            'https://app.crunch.io/api/datasets/',
+            '{"https://app.crunch.io/api/datasets/3/":{"is_published":true}}')
         expect_PATCH(is.published(ds) <- FALSE,
-            'api/datasets/',
-            '{"api/datasets/1/":{"is_published":false}}')
+            'https://app.crunch.io/api/datasets/',
+            '{"https://app.crunch.io/api/datasets/1/":{"is_published":false}}')
         expect_PATCH(is.draft(ds2) <- FALSE,
-            'api/datasets/',
-            '{"api/datasets/3/":{"is_published":true}}')
+            'https://app.crunch.io/api/datasets/',
+            '{"https://app.crunch.io/api/datasets/3/":{"is_published":true}}')
         expect_PATCH(is.draft(ds) <- TRUE,
-            'api/datasets/',
-            '{"api/datasets/1/":{"is_published":false}}')
+            'https://app.crunch.io/api/datasets/',
+            '{"https://app.crunch.io/api/datasets/1/":{"is_published":false}}')
         expect_PATCH(publish(ds2),
-            'api/datasets/',
-            '{"api/datasets/3/":{"is_published":true}}')
+            'https://app.crunch.io/api/datasets/',
+            '{"https://app.crunch.io/api/datasets/3/":{"is_published":true}}')
         expect_no_request(publish(ds))
         expect_no_request(is.draft(ds) <- FALSE)
         expect_no_request(is.published(ds) <- TRUE)
@@ -86,19 +86,19 @@ with_mock_HTTP({
 
     test_that("startDate<- makes correct request", {
         expect_PATCH(startDate(ds2) <- today,
-            'api/datasets/',
-            '{"api/datasets/3/":{"start_date":"2016-02-11"}}')
+            'https://app.crunch.io/api/datasets/',
+            '{"https://app.crunch.io/api/datasets/3/":{"start_date":"2016-02-11"}}')
         expect_PATCH(startDate(ds) <- NULL,
-            'api/datasets/',
-            '{"api/datasets/1/":{"start_date":null}}')
+            'https://app.crunch.io/api/datasets/',
+            '{"https://app.crunch.io/api/datasets/1/":{"start_date":null}}')
     })
     test_that("endDate<- makes correct request", {
         expect_PATCH(endDate(ds2) <- today,
-            'api/datasets/',
-            '{"api/datasets/3/":{"end_date":"2016-02-11"}}')
+            'https://app.crunch.io/api/datasets/',
+            '{"https://app.crunch.io/api/datasets/3/":{"end_date":"2016-02-11"}}')
         expect_PATCH(endDate(ds) <- NULL,
-            'api/datasets/',
-            '{"api/datasets/1/":{"end_date":null}}')
+            'https://app.crunch.io/api/datasets/',
+            '{"https://app.crunch.io/api/datasets/1/":{"end_date":null}}')
     })
 
     test_that("Dataset webURL", {
@@ -110,20 +110,20 @@ with_mock_HTTP({
 
     test_that("Dataset VariableCatalog index is ordered", {
         expect_identical(urls(variables(ds)),
-            c("api/datasets/1/variables/birthyr/",
-            "api/datasets/1/variables/gender/",
-            "api/datasets/1/variables/mymrset/",
-            "api/datasets/1/variables/textVar/",
-            "api/datasets/1/variables/starttime/",
-            "api/datasets/1/variables/catarray/"))
+            c("https://app.crunch.io/api/datasets/1/variables/birthyr/",
+            "https://app.crunch.io/api/datasets/1/variables/gender/",
+            "https://app.crunch.io/api/datasets/1/variables/mymrset/",
+            "https://app.crunch.io/api/datasets/1/variables/textVar/",
+            "https://app.crunch.io/api/datasets/1/variables/starttime/",
+            "https://app.crunch.io/api/datasets/1/variables/catarray/"))
         ## allVariables is ordered too
         expect_identical(urls(allVariables(ds)),
-            c("api/datasets/1/variables/birthyr/",
-            "api/datasets/1/variables/gender/",
-            "api/datasets/1/variables/mymrset/",
-            "api/datasets/1/variables/textVar/",
-            "api/datasets/1/variables/starttime/",
-            "api/datasets/1/variables/catarray/"))
+            c("https://app.crunch.io/api/datasets/1/variables/birthyr/",
+            "https://app.crunch.io/api/datasets/1/variables/gender/",
+            "https://app.crunch.io/api/datasets/1/variables/mymrset/",
+            "https://app.crunch.io/api/datasets/1/variables/textVar/",
+            "https://app.crunch.io/api/datasets/1/variables/starttime/",
+            "https://app.crunch.io/api/datasets/1/variables/catarray/"))
     })
 
     test_that("namekey function exists and affects names()", {
@@ -196,8 +196,8 @@ with_mock_HTTP({
     })
 
     test_that("Extract from dataset by VariableOrder/Group", {
-        ents <- c("api/datasets/1/variables/gender/",
-            "api/datasets/1/variables/mymrset/")
+        ents <- c("https://app.crunch.io/api/datasets/1/variables/gender/",
+            "https://app.crunch.io/api/datasets/1/variables/mymrset/")
         ord <- VariableOrder(VariableGroup("G1", entities=ents))
         expect_identical(ds[ord[[1]]], ds[c("gender", "mymrset")])
         expect_identical(ds[ord], ds[c("gender", "mymrset")])
@@ -226,12 +226,12 @@ with_mock_HTTP({
         expect_false(settings(ds)$viewers_can_export)
         expect_true(settings(ds)$viewers_can_change_weight)
         expect_identical(settings(ds)$weight, self(ds$birthyr))
-        expect_identical(self(settings(ds)), "api/datasets/1/settings/")
+        expect_identical(self(settings(ds)), "https://app.crunch.io/api/datasets/1/settings/")
     })
 
     test_that("Changing dataset settings", {
         expect_PATCH(settings(ds)$viewers_can_export <- TRUE,
-            "api/datasets/1/settings/",
+            "https://app.crunch.io/api/datasets/1/settings/",
             '{"viewers_can_export":true}')
     })
     test_that("No request made if not altering a setting", {
@@ -239,13 +239,13 @@ with_mock_HTTP({
     })
     test_that("Can set a NULL setting", {
         expect_PATCH(settings(ds)$viewers_can_export <- NULL,
-            "api/datasets/1/settings/",
+            "https://app.crunch.io/api/datasets/1/settings/",
             '{"viewers_can_export":null}')
     })
     test_that("Can set a variable as weight", {
         expect_PATCH(settings(ds)$weight <- ds$gender, ## Silly; server would reject, but just checking request
-            "api/datasets/1/settings/",
-            '{"weight":"api/datasets/1/variables/gender/"}')
+            "https://app.crunch.io/api/datasets/1/settings/",
+            '{"weight":"https://app.crunch.io/api/datasets/1/variables/gender/"}')
     })
     test_that("Can't add a setting that doesn't exist", {
         expect_error(settings(ds)$NOTASETTING <- TRUE,
@@ -253,10 +253,6 @@ with_mock_HTTP({
     })
     test_that("Dataset deleting", {
         expect_error(delete(ds), "Must confirm") ## New non-interactive behavior
-        expect_warning(
-            expect_error(delete(ds, confirm=TRUE), "Must confirm"),
-            "The 'confirm' argument is deprecated."
-        )
         with_consent(expect_DELETE(delete(ds), self(ds)))  ## No warning
     })
 })
