@@ -22,45 +22,43 @@ with_mock_HTTP({
 
     test_that("Simple project creation by assignment", {
         expect_POST(projects[["A new project"]] <- list(),
-            'api/projects/',
+            'https://app.crunch.io/api/projects/',
             '{"name":"A new project"}')
         expect_POST(projects$`A new project` <- list(),
-            'api/projects/',
+            'https://app.crunch.io/api/projects/',
             '{"name":"A new project"}')
     })
 
     test_that("Project creation with newProject", {
         expect_POST(newProject("A new project"),
-            'api/projects/',
+            'https://app.crunch.io/api/projects/',
             '{"name":"A new project"}')
-        with_POST("api/projects/project1/", {
+        with_POST("https://app.crunch.io/api/projects/project1/", {
             ## Mock the return of that creation
             pro <- newProject("This is being ignored")
             expect_is(pro, "CrunchProject")
             expect_identical(name(pro), "Project One")
             ## Now also check that the PATCH to add members happens
             expect_PATCH(newProject("A new project", members="new.user@crunch.io"),
-                'api/projects/project1/members/',
+                'https://app.crunch.io/api/projects/project1/members/',
                 '{"new.user@crunch.io":{}}')
         })
     })
 
     test_that("Project editing", {
         expect_PATCH(names(projects)[2] <- "New name",
-            'api/projects/',
-            '{"api/projects/project2/":{"name":"New name"}}')
+            'https://app.crunch.io/api/projects/',
+            '{"https://app.crunch.io/api/projects/project2/":{"name":"New name"}}')
         expect_PATCH(name(projects[[2]]) <- "New name",
-            'api/projects/',
-            '{"api/projects/project2/":{"name":"New name"}}')
+            'https://app.crunch.io/api/projects/',
+            '{"https://app.crunch.io/api/projects/project2/":{"name":"New name"}}')
     })
 
     test_that("Project deletion", {
-        expect_warning(
-            expect_error(delete(projects[[1]], confirm=TRUE),
-                "Must confirm deleting project"),
-            "The 'confirm' argument is deprecated.")
+        expect_error(delete(projects[[1]]),
+            "Must confirm deleting project")
         with(consent(), {
-            expect_DELETE(delete(projects[[1]]), "api/projects/project1/")
+            expect_DELETE(delete(projects[[1]]), "https://app.crunch.io/api/projects/project1/")
         })
     })
 
@@ -69,23 +67,31 @@ with_mock_HTTP({
         expect_is(m, "MemberCatalog")
         expect_identical(names(m), c("Fake User", "Roger User"))
         expect_identical(emails(m), c("fake.user@example.com", "roger.user@example.com"))
+        expect_identical(name(m[["roger.user@example.com"]]),
+            "Roger User")
+        expect_error(m[["NOTAUSER@example.com"]],
+            "Subscript out of bounds: NOTAUSER@example.com")
+        expect_identical(names(m["roger.user@example.com"]),
+            "Roger User")
+        expect_error(m["NOTAUSER@example.com"],
+            "Undefined elements selected: NOTAUSER@example.com")
     })
 
     test_that("Add members by members<-", {
         expect_PATCH(members(aproject) <- c("new.user@crunch.io", "foo@example.co"),
-            'api/projects/project1/members/',
+            'https://app.crunch.io/api/projects/project1/members/',
             '{"new.user@crunch.io":{},"foo@example.co":{}}')
     })
 
     test_that("Add members doesn't re-add if already a member", {
         expect_PATCH(members(aproject) <- c("new.user@crunch.io", "roger.user@example.com"),
-            'api/projects/project1/members/',
+            'https://app.crunch.io/api/projects/project1/members/',
             '{"new.user@crunch.io":{}}')
     })
 
     test_that("Remove members by <- NULL", {
         expect_PATCH(members(aproject)[["roger.user@example.com"]] <- NULL,
-            'api/projects/project1/members/',
+            'https://app.crunch.io/api/projects/project1/members/',
             '{"roger.user@example.com":null}')
     })
 
@@ -95,11 +101,11 @@ with_mock_HTTP({
 
     test_that("is.editor<- on member catalog", {
         expect_PATCH(is.editor(m) <- c(TRUE, TRUE),
-            'api/projects/project1/members/',
-            '{"api/users/user2/":{"permissions":{"edit":true}}}')
+            'https://app.crunch.io/api/projects/project1/members/',
+            '{"https://app.crunch.io/api/users/user2/":{"permissions":{"edit":true}}}')
         expect_PATCH(is.editor(m[2]) <- TRUE,
-            'api/projects/project1/members/',
-            '{"api/users/user2/":{"permissions":{"edit":true}}}')
+            'https://app.crunch.io/api/projects/project1/members/',
+            '{"https://app.crunch.io/api/users/user2/":{"permissions":{"edit":true}}}')
         expect_no_request(is.editor(m[2]) <- FALSE) ## No change, so no PATCH request made
     })
 
@@ -137,7 +143,7 @@ with_mock_HTTP({
     test_that("Project datasets order", {
         expect_is(do, "DatasetOrder")
         expect_identical(do@graph,
-            list(DatasetGroup("Group 1", "api/datasets/3/")))
+            list(DatasetGroup("Group 1", "https://app.crunch.io/api/datasets/3/")))
         expect_output(do,
             paste("[+] Group 1", "    ECON.sav", sep="\n"), fixed=TRUE)
     })
@@ -145,25 +151,25 @@ with_mock_HTTP({
     test_that("Add datasets to project by <- a dataset (which transfers ownership)", {
         ds <- loadDataset("test ds")
         expect_PATCH(datasets(aproject) <- ds,
-            'api/datasets/1/',
-            '{"owner":"api/projects/project1/"}')
+            'https://app.crunch.io/api/datasets/1/',
+            '{"owner":"https://app.crunch.io/api/projects/project1/"}')
     })
 
     test_that("Organize datasets", {
         expect_identical(DatasetOrder(DatasetGroup("new group", datasets(aproject))),
-            DatasetOrder(DatasetGroup("new group", "api/datasets/3/")))
+            DatasetOrder(DatasetGroup("new group", "https://app.crunch.io/api/datasets/3/")))
         expect_PUT(ordering(datasets(aproject)) <- DatasetOrder(DatasetGroup("new group",
             datasets(aproject))),
-            'api/projects/project1/datasets/order/',
-            '{"graph":[{"new group":["api/datasets/3/"]}]}')
-        nested.ord <- DatasetOrder("api/datasets/3/",
+            'https://app.crunch.io/api/projects/project1/datasets/order/',
+            '{"graph":[{"new group":["https://app.crunch.io/api/datasets/3/"]}]}')
+        nested.ord <- DatasetOrder("https://app.crunch.io/api/datasets/3/",
             DatasetGroup("new group",
-                list(DatasetGroup("nested", "api/datasets/3/"))),
+                list(DatasetGroup("nested", "https://app.crunch.io/api/datasets/3/"))),
             duplicates=TRUE)
         expect_PUT(ordering(datasets(aproject)) <- nested.ord,
-            'api/projects/project1/datasets/order/',
-            '{"graph":["api/datasets/3/",',
-            '{"new group":[{"nested":["api/datasets/3/"]}]}]}')
+            'https://app.crunch.io/api/projects/project1/datasets/order/',
+            '{"graph":["https://app.crunch.io/api/datasets/3/",',
+            '{"new group":[{"nested":["https://app.crunch.io/api/datasets/3/"]}]}]}')
     })
 })
 
